//---------------------------------------------------------------------------

#ifndef DevOfTheDayH
#define DevOfTheDayH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <ComCtrls.hpp>
#include <ExtCtrls.hpp>
#include <Graphics.hpp>
#include "rxricheditx.h"

//---------------------------------------------------------------------------
class TDevOfTheDay2 : public TForm
{
__published:	// IDE-managed Components
	TRichEdit *RichTipOld;
	TPanel *Panel1;
	TPanel *Panel3;
	TCheckBox *ckShowTip;
	TButton *btnOK;
	TPanel *Panel4;
	TImage *bmpDev;
	TLabel *Label1;
	void __fastcall btnOKClick(TObject *Sender);
	void __fastcall FormShow(TObject *Sender);
private:	// User declarations
public:		// User declarations
	TRxRichEditX *RichTip;
	__fastcall TDevOfTheDay2(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern PACKAGE TDevOfTheDay2 *DevOfTheDay2;
//---------------------------------------------------------------------------
#endif
